==> cscec5b-bpmana-api-3.0.0-20231014.080736-8-sources.jar: com/ejianc/business/bpmana/vo/BpmUserAnaVO.java <==
package com.ejianc.business.bpmana.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * <p>
 * 本类主要功能：个人流程分析报表
 * <p>
 * @version
 * @author sunq
 * @time 2023年5月
 */

public class BpmUserAnaVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String corpName;        // 人员所属公司
    private String userName;        // 人员名称
    private String userCode;        // 人员编码
    private String checkRole;       // 审批角色
    private String userId;          // 用户Id

    private String billtype;        // 单据类型
    private String procName;        // 流程名称
    private String checkProcNum;   // 审批流程数
    private String checkNodeNum;   // 审批节点数
    private String avgTime;         // 平均时长

    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getCheckRole() {
        return checkRole;
    }

    public void setCheckRole(String checkRole) {
        this.checkRole = checkRole;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public String getProcName() {
        return procName;
    }

    public void setProcName(String procName) {
        this.procName = procName;
    }

    public String getCheckProcNum() {
        return checkProcNum;
    }

    public void setCheckProcNum(String checkProcNum) {
        this.checkProcNum = checkProcNum;
    }

    public String getCheckNodeNum() {
        return checkNodeNum;
    }

    public void setCheckNodeNum(String checkNodeNum) {
        this.checkNodeNum = checkNodeNum;
    }

    public String getAvgTime() {
        return avgTime;
    }

    public void setAvgTime(String avgTime) {
        this.avgTime = avgTime;
    }
}

==> cscec5b-bpmana-api-3.0.0-20240303.083034-16-sources.jar: com/ejianc/business/bpmana/vo/BpmUserAnaVO.java <==
package com.ejianc.business.bpmana.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * <p>
 * 本类主要功能：个人流程分析报表
 * <p>
 * @version
 * @author sunq
 * @time 2023年5月
 */

public class BpmUserAnaVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String corpName;        // 人员所属公司
    private String userName;        // 人员名称
    private String userCode;        // 人员编码
    private String checkRole;       // 审批角色
    private String userId;          // 用户Id

    private String billtype;        // 单据类型
    private String procName;        // 流程名称
    private String checkProcNum;   // 审批流程数
    private String checkNodeNum;   // 审批节点数

    private String startTime;      //发起时间
    private String endTime;        //结束世间
    private String avgTime;        // 平均时长

    private String timeSpan; // 时间范围

    public String getCorpName() {
        return corpName;
    }

    public void setCorpName(String corpName) {
        this.corpName = corpName;
    }

    public String getUserName() {
        return userName;
    }

    public void setUserName(String userName) {
        this.userName = userName;
    }

    public String getUserCode() {
        return userCode;
    }

    public void setUserCode(String userCode) {
        this.userCode = userCode;
    }

    public String getCheckRole() {
        return checkRole;
    }

    public void setCheckRole(String checkRole) {
        this.checkRole = checkRole;
    }

    public String getUserId() {
        return userId;
    }

    public void setUserId(String userId) {
        this.userId = userId;
    }

    public String getBilltype() {
        return billtype;
    }

    public void setBilltype(String billtype) {
        this.billtype = billtype;
    }

    public String getProcName() {
        return procName;
    }

    public void setProcName(String procName) {
        this.procName = procName;
    }

    public String getCheckProcNum() {
        return checkProcNum;
    }

    public void setCheckProcNum(String checkProcNum) {
        this.checkProcNum = checkProcNum;
    }

    public String getCheckNodeNum() {
        return checkNodeNum;
    }

    public void setCheckNodeNum(String checkNodeNum) {
        this.checkNodeNum = checkNodeNum;
    }

    public String getStartTime(){return startTime;}

    public void setStartTime(String startTime){this.startTime = startTime;}

    public String getEndTime(){return endTime;}

    public void setEndTime(String endTime){this.endTime = endTime;}

    public String getAvgTime() {
        return avgTime;
    }

    public void setAvgTime(String avgTime) {
        this.avgTime = avgTime;
    }
}
